@@ -54,6 +54,10 @@ public:
      * @param numMines number of mines
      */
     void initField( int numRows, int numCols, int numMines );
+    /**
+     * Resets mines to the intial state.
+     */
+    void resetMines();
     /**
      * Resizes this graphics item so it fits in given rect
      */
